#!/usr/bin/python
import json
import os
import argparse

exclludedPostfixs = ('.h')
bdfContents = ''
nl = '\n'
pathSep = '/'

parser = argparse.ArgumentParser(description='Convert Bazel JSON to BDF. The JOSN converter can be found at: https://github.com/grailbio/bazel-compilation-database')
parser.add_argument('-b', '--BDFPath', help='Path to BDF for write or append')
parser.add_argument('-e', '--externalDirPrefix', help='Path to use as prefix with thirdparty include / source paths')
parser.add_argument('jsonPaths', nargs='+', help='Paths to JSON files')
parser.add_argument('-p', '--projectName', help='Name of the Bazel project')
parser.add_argument('-s', '--stdout', action='store_true', help='Write BDF to stdout rather than file.')
parser.add_argument('-w', '--workingDir', help='Base directory appended to relative paths')

args = parser.parse_args()

if not args.workingDir:
    args.workingDir = os.getcwd()
    print('Working diriectory not specified, assuming: ' + args.workingDir)
if not args.projectName:
    args.projectName = os.path.basename(args.workingDir)
    print('Project name not specified, assuming: ' + args.projectName)
if not args.externalDirPrefix:
    args.externalDirPrefix = args.workingDir + pathSep + 'bazel-' + args.projectName + pathSep
    print('External directoy path prefix not specified, assuming: ' + args.externalDirPrefix)
if not args.BDFPath:
    args.BDFPath = args.workingDir + pathSep + args.projectName + '.bdf'
    print('BDF path not specified, assuming: ' + args.BDFPath)

for path in args.jsonPaths:
    with open(path, 'r') as json_file:
        for item in json.load(json_file):
            if 'file' in item and not item['file'].endswith(exclludedPostfixs) and 'command' in item:
                bdfContents += '------- cpptestscan v.9.6.1.76 (cpptesttrace) -------' + nl
                bdfContents += 'working_dir=' + args.workingDir + nl
                bdfContents += 'project_name=' + args.projectName + nl
                for word in item['command'].split(' '):
                     if word.startswith('external'): word = args.externalDirPrefix + word
                     bdfContents += 'arg=' + word + nl

if args.stdout:
    print(bdfContents)
else:
    with open(args.BDFPath, 'a') as bdf: bdf.write(bdfContents)
